Venv-Pack
==========

|Build Status| |PyPI Badge|

``venv-pack`` is a command-line tool for packaging `virtual environments`_ for
distribution. Please refer to the documentation_ for more information.

For a similar tool for `conda environments`_, see `conda-pack`_

LICENSE
-------

New BSD. See the
`License File <https://github.com/jcrist/venv-pack/blob/master/LICENSE.txt>`_.

.. _documentation: https://jcrist.github.io/venv-pack/
.. _virtual environments: https://docs.python.org/3/tutorial/venv.html
.. _conda environments: https://conda.io
.. _conda-pack: https://conda.github.io/conda-pack/

.. |Build Status| image:: https://travis-ci.org/jcrist/venv-pack.svg?branch=master
   :target: https://travis-ci.org/jcrist/venv-pack
.. |PyPI Badge| image:: https://img.shields.io/pypi/v/venv-pack.svg
   :target: https://pypi.org/project/venv-pack/
